==> pgsql-help-2.5-br.tar.gz: topology_comments.sql <==

COMMENT ON TYPE topology.getfaceedges_returntype IS 'postgis type: Um tipo composto que consiste em um número sequência e um número limite. Este é o tipo retorno para ST_GetFaceEdges';

COMMENT ON TYPE topology.TopoGeometry IS 'postgis type: Um tipo composto representando uma geometria topologicamente definida';

COMMENT ON TYPE topology.validatetopology_returntype IS 'postgis type: Um tipo composto que consiste em um mensagem de erro e id1 e id2 para indicar a localização do erro. Este é o tipo retorno para ValidateTopology';

COMMENT ON DOMAIN topology.TopoElement IS 'postgis domain: Um arranjo de 2 inteiros geralmente usado para identificar um componente TopoGeometry.';

COMMENT ON DOMAIN topology.TopoElementArray IS 'postgis domain: Um banco de dados de objetos TopoElement';

COMMENT ON FUNCTION topology.AddTopoGeometryColumn(varchar , varchar , varchar , varchar , varchar ) IS 'args: topology_name, schema_name, table_name, column_name, feature_type - Adiciona uma coluna topogeometria a uma table, registra essa coluna nova como uma camada topology.layer e retorna a nova layer_id.';
			
COMMENT ON FUNCTION topology.AddTopoGeometryColumn(varchar , varchar , varchar , varchar , varchar , integer ) IS 'args: topology_name, schema_name, table_name, column_name, feature_type, child_layer - Adiciona uma coluna topogeometria a uma table, registra essa coluna nova como uma camada topology.layer e retorna a nova layer_id.';
			
COMMENT ON FUNCTION topology.DropTopology(varchar ) IS 'args: topology_schema_name - Cuidado ao usar: Derruba um esquema topologia e deleta sua referência da table topology.topology e referências para tables naquele esquema da table geometry_columns.';
			
COMMENT ON FUNCTION topology.DropTopoGeometryColumn(varchar , varchar , varchar ) IS 'args: schema_name, table_name, column_name - Derruba a coluna topogeometria da table nomeada table_name no esquema schema_name e tira os registros da';
			
COMMENT ON FUNCTION topology.Populate_Topology_Layer() IS 'Adds missing entries to topology.layer table by reading metadata from topo tables.';
			
COMMENT ON FUNCTION topology.TopologySummary(varchar ) IS 'args: topology_schema_name - Pega um nome de topologia e fornece totais resumidos de tipos dos objetos na topologia';
			
COMMENT ON FUNCTION topology.ValidateTopology(varchar ) IS 'args: topology_schema_name - Retorna um conjunto de objetos validatetopology_returntype detalhando issues com topologia';
			
COMMENT ON FUNCTION topology.CreateTopology(varchar ) IS 'args: topology_schema_name - Cria um novo esquema topologia e registra esse novo esquema na tabela topology.topology.';
			
COMMENT ON FUNCTION topology.CreateTopology(varchar , integer ) IS 'args: topology_schema_name, srid - Cria um novo esquema topologia e registra esse novo esquema na tabela topology.topology.';
			
COMMENT ON FUNCTION topology.CreateTopology(varchar , integer , double precision ) IS 'args: topology_schema_name, srid, prec - Cria um novo esquema topologia e registra esse novo esquema na tabela topology.topology.';
			
COMMENT ON FUNCTION topology.CreateTopology(varchar , integer , double precision , boolean ) IS 'args: topology_schema_name, srid, prec, hasz - Cria um novo esquema topologia e registra esse novo esquema na tabela topology.topology.';
			
COMMENT ON FUNCTION topology.CopyTopology(varchar , varchar ) IS 'args: existing_topology_name, new_name - Faz uma cópia da estrutura de uma topologia (nós, limites, faces, camadas e TopoGeometrias).';
			
COMMENT ON FUNCTION topology.ST_InitTopoGeo(varchar ) IS 'args: topology_schema_name - Cria um novo esquema topologia e registra esse novo esquema na table topology.topology e detalha um resumo do processo.';
			
COMMENT ON FUNCTION topology.ST_CreateTopoGeo(varchar , geometry ) IS 'args: atopology, acollection - Adiciona uma coleção de geometrias para uma dada topologia vazia e retorna uma mensagem detalhando sucesso.';
			
COMMENT ON FUNCTION topology.TopoGeo_AddPoint(varchar , geometry , float8 ) IS 'args: toponame, apoint, tolerance - Adiciona um ponto a uma topologia usando uma tolerância e possivelmente dividindo um limite existente.';
			
COMMENT ON FUNCTION topology.TopoGeo_AddLineString(varchar , geometry , float8 ) IS 'args: toponame, aline, tolerance - Adiciona uma linestring a ua topologia existente usando uma tolerância e possivelmente dividindo limites/faces existentes. Retorna identificadores de limites';
			
COMMENT ON FUNCTION topology.TopoGeo_AddPolygon(varchar , geometry , float8 ) IS 'args: atopology, apoly, atolerance - Adiciona um polígono a uma topologia usando uma tolerância e possivelmente dividindo limites/faces.';
			
COMMENT ON FUNCTION topology.ST_AddIsoNode(varchar , integer , geometry ) IS 'args: atopology, aface, apoint - Adiciona um nó isolado a uma face em uma topologia e retorna a id do novo nó. Se a face é nula, o nó continua sendo criado.';
			
COMMENT ON FUNCTION topology.ST_AddIsoEdge(varchar , integer , integer , geometry ) IS 'args: atopology, anode, anothernode, alinestring - Adiciona um limite isolado definido pela geometria alinestring a uma topologia conectando dois nós isoladosanode e anothernode e retorna a nova id do novo limite.';
			
COMMENT ON FUNCTION topology.ST_AddEdgeNewFaces(varchar , integer , integer , geometry ) IS 'args: atopology, anode, anothernode, acurve - Adiciona um novo limite e, se uma face for dividida, deleta a face original e substitui por duas novas faces.';
			
COMMENT ON FUNCTION topology.ST_AddEdgeModFace(varchar , integer , integer , geometry ) IS 'args: atopology, anode, anothernode, acurve - Adiciona um novo limite e, se uma face for dividida, modifica a face original e adiciona uma nova face.';
			
COMMENT ON FUNCTION topology.ST_RemEdgeNewFace(varchar , integer ) IS 'args: atopology, anedge - Remove um limite e, se o limite removido separava duas faces, deleta as faces originais e as substitui por uma nova face.';
			
COMMENT ON FUNCTION topology.ST_RemEdgeModFace(varchar , integer ) IS 'args: atopology, anedge - Remove um limite e, se o limite removido separou duas faces, deleta uma das duas e modifica a outra para pegar o espaço delas.';
			
COMMENT ON FUNCTION topology.ST_ChangeEdgeGeom(varchar , integer , geometry ) IS 'args: atopology, anedge, acurve - Modifica a forma de um limite sem afetar a estrutura da topologia.';
			
COMMENT ON FUNCTION topology.ST_ModEdgeSplit(varchar , integer , geometry ) IS 'args: atopology, anedge, apoint - Divide um limite criando um novo nó junto de um limite existente, modificando o limite original e adicionando um novo limite.';
			
COMMENT ON FUNCTION topology.ST_ModEdgeHeal(varchar , integer , integer ) IS 'args: atopology, anedge, anotheredge - Fecha dois limites deletando o nó que os conecta, modificando o primeiro limite e deletando o segundo. Retorna a id do nó deletado.';
			
COMMENT ON FUNCTION topology.ST_NewEdgeHeal(varchar , integer , integer ) IS 'args: atopology, anedge, anotheredge - Fecha dois limites deletando o nó que os conecta, deletando ambos limites, e substituindo-os com um limite cuja direção é a mesma do primeiro limite fornecido.';
			
COMMENT ON FUNCTION topology.ST_MoveIsoNode(varchar , integer , geometry ) IS 'args: atopology, anedge, apoint - Moves an isolated node in a topology from one point to another. If new apoint geometry exists as a node an error is thrown. Returns description of move.';
			
COMMENT ON FUNCTION topology.ST_NewEdgesSplit(varchar , integer , geometry ) IS 'args: atopology, anedge, apoint - Divide um limite criando um novo nó ao longo do limite existente, deletando o limite original e substituindo-o por dois novos. Retorna a id do novo nó criado que integra os novos limites.';
			
COMMENT ON FUNCTION topology.ST_RemoveIsoNode(varchar , integer ) IS 'args: atopology, anode - Remove um nó isolado e retorna descrição de ação. Se o nó não for isolado (for começo ou fim de um limite), então, uma exceção é lançada.';
			
COMMENT ON FUNCTION topology.ST_RemoveIsoEdge(varchar , integer ) IS 'args: atopology, anedge - Removes an isolated edge and returns description of action. If the edge is not isolated, then an exception is thrown.';
			
COMMENT ON FUNCTION topology.GetEdgeByPoint(varchar , geometry , float8 ) IS 'args: atopology, apoint, tol - Encontra a edge-id de um limite que intercepta um dado ponto';
			
COMMENT ON FUNCTION topology.GetFaceByPoint(varchar , geometry , float8 ) IS 'args: atopology, apoint, tol - Encontra a face-id de uma face que intersecta um dado ponto';
			
COMMENT ON FUNCTION topology.GetNodeByPoint(varchar , geometry , float8 ) IS 'args: atopology, point, tol - Encontra a id de um nó em uma localização de ponto';
			
COMMENT ON FUNCTION topology.GetTopologyID(varchar) IS 'args: toponame - Retorna a id de uma topologia na table topology.topology dado o nome da topologia.';
			
COMMENT ON FUNCTION topology.GetTopologyID(varchar) IS 'args: toponame - Retorna o SRID de uma topologia na table topology.topology dado o nome da topologia.';
			
COMMENT ON FUNCTION topology.GetTopologyName(integer) IS 'args: topology_id - Retorna o nome de uma topologia (esquema) dada a id da topologia.';
			
COMMENT ON FUNCTION topology.ST_GetFaceEdges(varchar , integer ) IS 'args: atopology, aface - Retorna um conjunto de limites ordenados que amarram aface.';
			
COMMENT ON FUNCTION topology.ST_GetFaceGeometry(varchar , integer ) IS 'args: atopology, aface - Retorna o polígono na topologia dada com a id de face especificada.';
			
COMMENT ON FUNCTION topology.GetRingEdges(varchar , integer , integer ) IS 'args: atopology, aring, max_edges=null - Retorna o conjunto ordenado de identificadores de limites assinados, conhecidos caminhando em um lado da beirada.';
			
COMMENT ON FUNCTION topology.GetNodeEdges(varchar , integer ) IS 'args: atopology, anode - Retorna um conjunto ordenado de limites incidentes no dado nó.';
			
COMMENT ON FUNCTION topology.Polygonize(varchar ) IS 'args: toponame - Encontra e registra todas faces definidas pelos limites da topologia';
			
COMMENT ON FUNCTION topology.AddNode(varchar , geometry , boolean , boolean ) IS 'args: toponame, apoint, allowEdgeSplitting=false, computeContainingFace=false - Adiciona um ponto nó na table nó no esquema topológico específico e retorna a nodeid do novo nó. Se o ponto já existe, a nodeid é retornada.';
			
COMMENT ON FUNCTION topology.AddEdge(varchar , geometry ) IS 'args: toponame, aline - Adiciona uma linestring limite à edge table e os pontos de início e fim associados à table ponto nó do esquema de topologia especificado usando a linestring geometria específica e retorna a bordaid da nova borda (ou da borda já existente).';
			
COMMENT ON FUNCTION topology.AddFace(varchar , geometry , boolean ) IS 'args: toponame, apolygon, force_new=false - Registra uma face primitiva a uma topologia e pega seu identificador.';
			
COMMENT ON FUNCTION topology.ST_Simplify(TopoGeometry, float) IS 'args: geomA, tolerance - Retorna uma versão "simplificada" da geometria da dada TopoGeometria usando o algorítimo Douglas-Peucker.';
			
COMMENT ON FUNCTION topology.CreateTopoGeom(varchar , integer , integer, topoelementarray) IS 'args: toponame, tg_type, layer_id, tg_objs - Cria uma novo objeto de topo geometria de um arranjo topo elemento - tg_type: 1:[multi]point, 2:[multi]line, 3:[multi]poly, 4:collection';
			
COMMENT ON FUNCTION topology.CreateTopoGeom(varchar , integer , integer) IS 'args: toponame, tg_type, layer_id - Cria uma novo objeto de topo geometria de um arranjo topo elemento - tg_type: 1:[multi]point, 2:[multi]line, 3:[multi]poly, 4:collection';
			
COMMENT ON FUNCTION topology.toTopoGeom(geometry , varchar , integer, float8) IS 'args: geom, toponame, layer_id, tolerance - Converte uma simples geometria em uma topo geometria';
			
COMMENT ON FUNCTION topology.toTopoGeom(geometry , topogeometry , float8) IS 'args: geom, topogeom, tolerance - Converte uma simples geometria em uma topo geometria';
			
COMMENT ON AGGREGATE topology.TopoElementArray_Agg(topoelement) IS 'args: tefield - Retorna um topoelementarray para um conjunto de arranjos element_id, type (topoelementos)';
			
COMMENT ON FUNCTION topology.clearTopoGeom(topogeometry ) IS 'args: topogeom - Limpa o conteúdo de uma topo geometria';
			
COMMENT ON FUNCTION topology.TopoGeom_addElement(topogeometry , topoelement ) IS 'args: tg, el - Adiciona um elemento à definição de uma TopoGeometria';
			
COMMENT ON FUNCTION topology.TopoGeom_remElement(topogeometry , topoelement ) IS 'args: tg, el - Remove um elemento de uma definição de uma TopoGeometria';
			
COMMENT ON FUNCTION topology.GetTopoGeomElementArray(varchar , integer , integer) IS 'args: toponame, layer_id, tg_id - Retorna um topoelementarray (um arranjo de topoelementos) contendo os tipos e elementos topológicos da TopoGeometria (elementos primitivos)';
			
COMMENT ON FUNCTION topology.GetTopoGeomElementArray(topogeometry ) IS 'args: tg - Retorna um topoelementarray (um arranjo de topoelementos) contendo os tipos e elementos topológicos da TopoGeometria (elementos primitivos)';
			
COMMENT ON FUNCTION topology.GetTopoGeomElements(varchar , integer , integer) IS 'args: toponame, layer_id, tg_id - Retorna um conjunto de objetos topoelement contendo os topological element_id,element_type da TopoGeometria (elementos primitivos)';
			
COMMENT ON FUNCTION topology.GetTopoGeomElements(topogeometry ) IS 'args: tg - Retorna um conjunto de objetos topoelement contendo os topological element_id,element_type da TopoGeometria (elementos primitivos)';
			
COMMENT ON FUNCTION topology.AsGML(topogeometry ) IS 'args: tg - Retorna a representação GML de uma topogeometria.';
			
COMMENT ON FUNCTION topology.AsGML(topogeometry , text ) IS 'args: tg, nsprefix_in - Retorna a representação GML de uma topogeometria.';
			
COMMENT ON FUNCTION topology.AsGML(topogeometry , regclass ) IS 'args: tg, visitedTable - Retorna a representação GML de uma topogeometria.';
			
COMMENT ON FUNCTION topology.AsGML(topogeometry , regclass , text ) IS 'args: tg, visitedTable, nsprefix - Retorna a representação GML de uma topogeometria.';
			
COMMENT ON FUNCTION topology.AsGML(topogeometry , text , integer , integer ) IS 'args: tg, nsprefix_in, precision, options - Retorna a representação GML de uma topogeometria.';
			
COMMENT ON FUNCTION topology.AsGML(topogeometry , text , integer , integer , regclass ) IS 'args: tg, nsprefix_in, precision, options, visitedTable - Retorna a representação GML de uma topogeometria.';
			
COMMENT ON FUNCTION topology.AsGML(topogeometry , text , integer , integer , regclass , text ) IS 'args: tg, nsprefix_in, precision, options, visitedTable, idprefix - Retorna a representação GML de uma topogeometria.';
			
COMMENT ON FUNCTION topology.AsGML(topogeometry , text , integer , integer , regclass , text , int ) IS 'args: tg, nsprefix_in, precision, options, visitedTable, idprefix, gmlversion - Retorna a representação GML de uma topogeometria.';
			
COMMENT ON FUNCTION topology.AsTopoJSON(topogeometry , regclass ) IS 'args: tg, edgeMapTable - Retorna a representação TopoJSON de uma topogeometria.';
			
COMMENT ON FUNCTION topology.Equals(topogeometry , topogeometry ) IS 'args: tg1, tg2 - Retorna verdade se duas topogeometrias forem compostas da mesma topologia primitiva';
			
COMMENT ON FUNCTION topology.Intersects(topogeometry , topogeometry ) IS 'args: tg1, tg2 - Retorna verdade se algum par de primitivos das duas topologias se intersectar.';

==> pgsql-help-3.0-br.tar.gz: topology_comments.sql <==

COMMENT ON TYPE topology.getfaceedges_returntype IS 'postgis type: Um tipo composto que consiste em um número sequência e um número limite. Este é o tipo retorno para ST_GetFaceEdges';

COMMENT ON TYPE topology.TopoGeometry IS 'postgis type: Um tipo composto representando uma geometria topologicamente definida';

COMMENT ON TYPE topology.validatetopology_returntype IS 'postgis type: Um tipo composto que consiste em um mensagem de erro e id1 e id2 para indicar a localização do erro. Este é o tipo retorno para ValidateTopology';

COMMENT ON DOMAIN topology.TopoElement IS 'postgis domain: Um arranjo de 2 inteiros geralmente usado para identificar um componente TopoGeometry.';

COMMENT ON DOMAIN topology.TopoElementArray IS 'postgis domain: Um banco de dados de objetos TopoElement';

COMMENT ON FUNCTION topology.AddTopoGeometryColumn(varchar , varchar , varchar , varchar , varchar ) IS 'args: topology_name, schema_name, table_name, column_name, feature_type - Adiciona uma coluna topogeometria a uma table, registra essa coluna nova como uma camada topology.layer e retorna a nova layer_id.';
			
COMMENT ON FUNCTION topology.AddTopoGeometryColumn(varchar , varchar , varchar , varchar , varchar , integer ) IS 'args: topology_name, schema_name, table_name, column_name, feature_type, child_layer - Adiciona uma coluna topogeometria a uma table, registra essa coluna nova como uma camada topology.layer e retorna a nova layer_id.';
			
COMMENT ON FUNCTION topology.DropTopology(varchar ) IS 'args: topology_schema_name - Cuidado ao usar: Derruba um esquema topologia e deleta sua referência da table topology.topology e referências para tables naquele esquema da table geometry_columns.';
			
COMMENT ON FUNCTION topology.DropTopoGeometryColumn(varchar , varchar , varchar ) IS 'args: schema_name, table_name, column_name - Derruba a coluna topogeometria da table nomeada table_name no esquema schema_name e tira os registros da';
			
COMMENT ON FUNCTION topology.Populate_Topology_Layer() IS 'Adds missing entries to topology.layer table by reading metadata from topo tables.';
			
COMMENT ON FUNCTION topology.TopologySummary(varchar ) IS 'args: topology_schema_name - Pega um nome de topologia e fornece totais resumidos de tipos dos objetos na topologia.';
			
COMMENT ON FUNCTION topology.ValidateTopology(varchar ) IS 'args: topology_schema_name - Retorna um conjunto de objetos validatetopology_returntype detalhando issues com topologia';
			
COMMENT ON FUNCTION topology.CreateTopology(varchar ) IS 'args: topology_schema_name - Cria um novo esquema topologia e registra esse novo esquema na tabela topology.topology.';
			
COMMENT ON FUNCTION topology.CreateTopology(varchar , integer ) IS 'args: topology_schema_name, srid - Cria um novo esquema topologia e registra esse novo esquema na tabela topology.topology.';
			
COMMENT ON FUNCTION topology.CreateTopology(varchar , integer , double precision ) IS 'args: topology_schema_name, srid, prec - Cria um novo esquema topologia e registra esse novo esquema na tabela topology.topology.';
			
COMMENT ON FUNCTION topology.CreateTopology(varchar , integer , double precision , boolean ) IS 'args: topology_schema_name, srid, prec, hasz - Cria um novo esquema topologia e registra esse novo esquema na tabela topology.topology.';
			
COMMENT ON FUNCTION topology.CopyTopology(varchar , varchar ) IS 'args: existing_topology_name, new_name - Faz uma cópia da estrutura de uma topologia (nós, limites, faces, camadas e TopoGeometrias).';
			
COMMENT ON FUNCTION topology.ST_InitTopoGeo(varchar ) IS 'args: topology_schema_name - Cria um novo esquema topologia e registra esse novo esquema na table topology.topology e detalha um resumo do processo.';
			
COMMENT ON FUNCTION topology.ST_CreateTopoGeo(varchar , geometry ) IS 'args: atopology, acollection - Adiciona uma coleção de geometrias para uma dada topologia vazia e retorna uma mensagem detalhando sucesso.';
			
COMMENT ON FUNCTION topology.TopoGeo_AddPoint(varchar , geometry , float8 ) IS 'args: toponame, apoint, tolerance - Adiciona um ponto a uma topologia usando uma tolerância e possivelmente dividindo um limite existente.';
			
COMMENT ON FUNCTION topology.TopoGeo_AddLineString(varchar , geometry , float8 ) IS 'args: toponame, aline, tolerance - Adiciona uma linestring a ua topologia existente usando uma tolerância e possivelmente dividindo limites/faces existentes. Retorna identificadores de limites';
			
COMMENT ON FUNCTION topology.TopoGeo_AddPolygon(varchar , geometry , float8 ) IS 'args: atopology, apoly, atolerance - Adiciona uma linestring a ua topologia existente usando uma tolerância e possivelmente dividindo limites/faces existentes. Retorna identificadores de limites';
			
COMMENT ON FUNCTION topology.ST_AddIsoNode(varchar , integer , geometry ) IS 'args: atopology, aface, apoint - Adiciona um nó isolado a uma face em uma topologia e retorna a id do novo nó. Se a face é nula, o nó continua sendo criado.';
			
COMMENT ON FUNCTION topology.ST_AddIsoEdge(varchar , integer , integer , geometry ) IS 'args: atopology, anode, anothernode, alinestring - Adiciona um limite isolado definido pela geometria alinestring a uma topologia conectando dois nós isoladosanode e anothernode e retorna a nova id do novo limite.';
			
COMMENT ON FUNCTION topology.ST_AddEdgeNewFaces(varchar , integer , integer , geometry ) IS 'args: atopology, anode, anothernode, acurve - Adiciona um novo limite e, se uma face for dividida, deleta a face original e substitui por duas novas faces.';
			
COMMENT ON FUNCTION topology.ST_AddEdgeModFace(varchar , integer , integer , geometry ) IS 'args: atopology, anode, anothernode, acurve - Adiciona um novo limite e, se uma face for dividida, modifica a face original e adiciona uma nova face.';
			
COMMENT ON FUNCTION topology.ST_RemEdgeNewFace(varchar , integer ) IS 'args: atopology, anedge - Remove um limite e, se o limite removido separava duas faces, deleta as faces originais e as substitui por uma nova face.';
			
COMMENT ON FUNCTION topology.ST_RemEdgeModFace(varchar , integer ) IS 'args: atopology, anedge - Remove um limite e, se o limite removido separou duas faces, deleta uma das duas e modifica a outra para pegar o espaço delas.';
			
COMMENT ON FUNCTION topology.ST_ChangeEdgeGeom(varchar , integer , geometry ) IS 'args: atopology, anedge, acurve - Modifica a forma de um limite sem afetar a estrutura da topologia.';
			
COMMENT ON FUNCTION topology.ST_ModEdgeSplit(varchar , integer , geometry ) IS 'args: atopology, anedge, apoint - Divide um limite criando um novo nó junto de um limite existente, modificando o limite original e adicionando um novo limite.';
			
COMMENT ON FUNCTION topology.ST_ModEdgeHeal(varchar , integer , integer ) IS 'args: atopology, anedge, anotheredge - Fecha dois limites deletando o nó que os conecta, modificando o primeiro limite e deletando o segundo. Retorna a id do nó deletado.';
			
COMMENT ON FUNCTION topology.ST_NewEdgeHeal(varchar , integer , integer ) IS 'args: atopology, anedge, anotheredge - Fecha dois limites deletando o nó que os conecta, deletando ambos limites, e substituindo-os com um limite cuja direção é a mesma do primeiro limite fornecido.';
			
COMMENT ON FUNCTION topology.ST_MoveIsoNode(varchar , integer , geometry ) IS 'args: atopology, anedge, apoint - Moves an isolated node in a topology from one point to another. If new apoint geometry exists as a node an error is thrown. Returns description of move.';
			
COMMENT ON FUNCTION topology.ST_NewEdgesSplit(varchar , integer , geometry ) IS 'args: atopology, anedge, apoint - Divide um limite criando um novo nó ao longo do limite existente, deletando o limite original e substituindo-o por dois novos. Retorna a id do novo nó criado que integra os novos limites.';
			
COMMENT ON FUNCTION topology.ST_RemoveIsoNode(varchar , integer ) IS 'args: atopology, anode - Remove um nó isolado e retorna descrição de ação. Se o nó não for isolado (for começo ou fim de um limite), então, uma exceção é lançada.';
			
COMMENT ON FUNCTION topology.ST_RemoveIsoEdge(varchar , integer ) IS 'args: atopology, anedge - Removes an isolated edge and returns description of action. If the edge is not isolated, then an exception is thrown.';
			
COMMENT ON FUNCTION topology.GetEdgeByPoint(varchar , geometry , float8 ) IS 'args: atopology, apoint, tol - Encontra a edge-id de um limite que intercepta um dado ponto';
			
COMMENT ON FUNCTION topology.GetFaceByPoint(varchar , geometry , float8 ) IS 'args: atopology, apoint, tol - Encontra a face-id de uma face que intersecta um dado ponto';
			
COMMENT ON FUNCTION topology.GetNodeByPoint(varchar , geometry , float8 ) IS 'args: atopology, point, tol - Encontra a id de um nó em uma localização de ponto';
			
COMMENT ON FUNCTION topology.GetTopologyID(varchar) IS 'args: toponame - Retorna a id de uma topologia na table topology.topology dado o nome da topologia.';
			
COMMENT ON FUNCTION topology.GetTopologyID(varchar) IS 'args: toponame - Retorna o SRID de uma topologia na table topology.topology dado o nome da topologia.';
			
COMMENT ON FUNCTION topology.GetTopologyName(integer) IS 'args: topology_id - Retorna o nome de uma topologia (esquema) dada a id da topologia.';
			
COMMENT ON FUNCTION topology.ST_GetFaceEdges(varchar , integer ) IS 'args: atopology, aface - Retorna um conjunto de limites ordenados que amarram aface.';
			
COMMENT ON FUNCTION topology.ST_GetFaceGeometry(varchar , integer ) IS 'args: atopology, aface - Retorna o polígono na topologia dada com a id de face especificada.';
			
COMMENT ON FUNCTION topology.GetRingEdges(varchar , integer , integer ) IS 'args: atopology, aring, max_edges=null - Retorna o conjunto ordenado de identificadores de limites assinados, conhecidos caminhando em um lado da beirada.';
			
COMMENT ON FUNCTION topology.GetNodeEdges(varchar , integer ) IS 'args: atopology, anode - Retorna um conjunto ordenado de limites incidentes no dado nó.';
			
COMMENT ON FUNCTION topology.Polygonize(varchar ) IS 'args: toponame - Encontra e registra todas faces definidas pelos limites da topologia';
			
COMMENT ON FUNCTION topology.AddNode(varchar , geometry , boolean , boolean ) IS 'args: toponame, apoint, allowEdgeSplitting=false, computeContainingFace=false - Adiciona um ponto nó na table nó no esquema topológico específico e retorna a nodeid do novo nó. Se o ponto já existe, a nodeid é retornada.';
			
COMMENT ON FUNCTION topology.AddEdge(varchar , geometry ) IS 'args: toponame, aline - Adiciona uma linestring limite à edge table e os pontos de início e fim associados à table ponto nó do esquema de topologia especificado usando a linestring geometria específica e retorna a bordaid da nova borda (ou da borda já existente).';
			
COMMENT ON FUNCTION topology.AddFace(varchar , geometry , boolean ) IS 'args: toponame, apolygon, force_new=false - Registra uma face primitiva a uma topologia e pega seu identificador.';
			
COMMENT ON FUNCTION topology.ST_Simplify(TopoGeometry, float) IS 'args: geomA, tolerance - Retorna uma versão "simplificada" da geometria da dada TopoGeometria usando o algorítimo Douglas-Peucker.';
			
COMMENT ON FUNCTION topology.CreateTopoGeom(varchar , integer , integer, topoelementarray) IS 'args: toponame, tg_type, layer_id, tg_objs - Cria uma novo objeto de topo geometria de um arranjo topo elemento - tg_type: 1:[multi]point, 2:[multi]line, 3:[multi]poly, 4:collection';
			
COMMENT ON FUNCTION topology.CreateTopoGeom(varchar , integer , integer) IS 'args: toponame, tg_type, layer_id - Cria uma novo objeto de topo geometria de um arranjo topo elemento - tg_type: 1:[multi]point, 2:[multi]line, 3:[multi]poly, 4:collection';
			
COMMENT ON FUNCTION topology.toTopoGeom(geometry , varchar , integer, float8) IS 'args: geom, toponame, layer_id, tolerance - Converte uma simples geometria em uma topo geometria';
			
COMMENT ON FUNCTION topology.toTopoGeom(geometry , topogeometry , float8) IS 'args: geom, topogeom, tolerance - Converte uma simples geometria em uma topo geometria';
			
COMMENT ON AGGREGATE topology.TopoElementArray_Agg(topoelement) IS 'args: tefield - Retorna um topoelementarray para um conjunto de arranjos element_id, type (topoelementos)';
			
COMMENT ON FUNCTION topology.clearTopoGeom(topogeometry ) IS 'args: topogeom - Limpa o conteúdo de uma topo geometria';
			
COMMENT ON FUNCTION topology.TopoGeom_addElement(topogeometry , topoelement ) IS 'args: tg, el - Adiciona um elemento à definição de uma TopoGeometria';
			
COMMENT ON FUNCTION topology.TopoGeom_remElement(topogeometry , topoelement ) IS 'args: tg, el - Remove um elemento de uma definição de uma TopoGeometria';
			
COMMENT ON FUNCTION topology.GetTopoGeomElementArray(varchar , integer , integer) IS 'args: toponame, layer_id, tg_id - Retorna um topoelementarray (um arranjo de topoelementos) contendo os tipos e elementos topológicos da TopoGeometria (elementos primitivos)';
			
COMMENT ON FUNCTION topology.GetTopoGeomElementArray(topogeometry ) IS 'args: tg - Retorna um topoelementarray (um arranjo de topoelementos) contendo os tipos e elementos topológicos da TopoGeometria (elementos primitivos)';
			
COMMENT ON FUNCTION topology.GetTopoGeomElements(varchar , integer , integer) IS 'args: toponame, layer_id, tg_id - Retorna um conjunto de objetos topoelement contendo os topological element_id,element_type da TopoGeometria (elementos primitivos)';
			
COMMENT ON FUNCTION topology.GetTopoGeomElements(topogeometry ) IS 'args: tg - Retorna um conjunto de objetos topoelement contendo os topological element_id,element_type da TopoGeometria (elementos primitivos)';
			
COMMENT ON FUNCTION topology.AsGML(topogeometry ) IS 'args: tg - Retorna a representação GML de uma topogeometria.';
			
COMMENT ON FUNCTION topology.AsGML(topogeometry , text ) IS 'args: tg, nsprefix_in - Retorna a representação GML de uma topogeometria.';
			
COMMENT ON FUNCTION topology.AsGML(topogeometry , regclass ) IS 'args: tg, visitedTable - Retorna a representação GML de uma topogeometria.';
			
COMMENT ON FUNCTION topology.AsGML(topogeometry , regclass , text ) IS 'args: tg, visitedTable, nsprefix - Retorna a representação GML de uma topogeometria.';
			
COMMENT ON FUNCTION topology.AsGML(topogeometry , text , integer , integer ) IS 'args: tg, nsprefix_in, precision, options - Retorna a representação GML de uma topogeometria.';
			
COMMENT ON FUNCTION topology.AsGML(topogeometry , text , integer , integer , regclass ) IS 'args: tg, nsprefix_in, precision, options, visitedTable - Retorna a representação GML de uma topogeometria.';
			
COMMENT ON FUNCTION topology.AsGML(topogeometry , text , integer , integer , regclass , text ) IS 'args: tg, nsprefix_in, precision, options, visitedTable, idprefix - Retorna a representação GML de uma topogeometria.';
			
COMMENT ON FUNCTION topology.AsGML(topogeometry , text , integer , integer , regclass , text , int ) IS 'args: tg, nsprefix_in, precision, options, visitedTable, idprefix, gmlversion - Retorna a representação GML de uma topogeometria.';
			
COMMENT ON FUNCTION topology.AsTopoJSON(topogeometry , regclass ) IS 'args: tg, edgeMapTable - Retorna a representação TopoJSON de uma topogeometria.';
			
COMMENT ON FUNCTION topology.Equals(topogeometry , topogeometry ) IS 'args: tg1, tg2 - Retorna verdade se duas topogeometrias forem compostas da mesma topologia primitiva';
			
COMMENT ON FUNCTION topology.Intersects(topogeometry , topogeometry ) IS 'args: tg1, tg2 - Retorna verdade se algum par de primitivos das duas topologias se intersectar.';
